@@ -305,17 +305,23 @@ Scalar::Util module, but there are a couple that provide functions not
 catered to by that module.
 
 Please use the versions in L<Scalar::Util> in preference to these
-functions.
+functions.  In fact, if you use these functions in your production
+code then you may have to rewrite it some day.  They are retained only
+because they are "mostly harmless".
 
 =over
 
 =item B<blessed>
 
+B<Do not use in production code>
+
 Returns a true value if the passed reference (RV) is blessed.  See
 also L<Acme::Holy>.
 
 =item B<reftype>
 
+B<Do not use in production code>
+
 A bit like the perl built-in C<ref> function, but returns the I<type>
 of reference; ie, if the reference is blessed then it returns what
 C<ref> would have if it were not blessed.  Useful for "seeing through"
@@ -323,12 +329,16 @@ blessed references.
 
 =item B<refaddr>
 
+B<Do not use in production code>
+
 Returns the memory address of a scalar.  B<Warning>: this is I<not>
 guaranteed to be unique for scalars created in a program; memory might
 get re-used!
 
 =item B<is_int>, B<is_string>, B<is_double>
 
+B<Do not use in production code>
+
 A quick way of checking the three bits on scalars - IOK (is_int), NOK
 (is_double) and POK (is_string).  Note that the exact behaviour of
 when these bits get set is not defined by the perl API.
@@ -338,10 +348,14 @@ with caution.
 
 =item B<is_overloaded>
 
+B<Do not use in production code>
+
 A quick way to check if an object has overload magic on it.
 
 =item B<ish_int>
 
+B<Deprecated and will be removed in 2014>
+
 This function returns true, if the value it is passed looks like it
 I<already is> a representation of an I<integer>.  This is so that you
 can decide whether the value passed is a hash key or an array
@@ -349,18 +363,16 @@ index.
 
 =item B<is_key>
 
-This function returns true, if the value it is passed looks more like
-an I<index> to a collection than a I<value> of a collection.
+B<Deprecated and will be removed in 2014>
 
-But wait, you say - Set::Object has no indices, one of the fundamental
-properties of a Set is that it is an I<unordered collection>.  Which
-means I<no indices>.  Well, if this module were ever to be derived to
-be a more general multi-purpose collection, then this (and C<ish_int>)
-might be a good function to use to distinguish different types of
-indexes from values.
+This function returns true, if the value it is passed looks more like
+an I<index> to a collection than a I<value> of a collection.  Similar
+to the looks_like_number internal function, but weird.  Avoid.
 
 =item B<get_magic>
 
+B<Do not use in production code>
+
 Pass to a scalar, and get the magick wand (C<mg_obj>) used by the weak
 set implementation.  The return will be a list of integers which are
 pointers to the actual C<ISET> structure.  Whatever you do don't
@@ -509,7 +521,7 @@ require AutoLoader;
 
 @EXPORT_OK = qw( ish_int is_int is_string is_double blessed reftype
 		 refaddr is_overloaded is_object is_key set weak_set );
-$VERSION = '1.28';
+$VERSION = '1.29';
 
 bootstrap Set::Object $VERSION;
 
@@ -934,7 +946,7 @@ sub is_key {
 	    return is_key(&$sub($_[0]));
 	} elsif ($sub = UNIVERSAL::can($_[0], '(""')) {
 	    return is_key(&$sub($_[0]));
-	} elsif ($sub = UNIVERAL::can($_[0], '(nomethod')) {
+	} elsif ($sub = UNIVERSAL::can($_[0], '(nomethod')) {
 	    return is_key(&$sub($_[0]));
 	} else {
 	    return undef;
